#
# spec file for package apache-commons-parent
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define base_name       parent
%define short_name      commons-%{base_name}
Name:           apache-%{short_name}
Version:        78
Release:        1.1
Summary:        Apache Commons Parent Pom
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://commons.apache.org/commons-parent-pom.html
Source0:        https://github.com/apache/%{short_name}/archive/refs/tags/rel/%{short_name}-%{version}.tar.gz
BuildRequires:  javapackages-local
BuildRequires:  xmvn-resolve
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-assembly-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-compiler-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-jar-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-surefire-plugin)
BuildRequires:  mvn(org.apache:apache:pom:)
# Not generated automatically
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
Requires:       mvn(org.apache:apache:pom:)
Requires:       mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildArch:      noarch

%description
The Project Object Model files for the apache-commons packages.

%prep
%setup -q -n %{short_name}-rel-%{short_name}-%{version}

# Plugin is not in suse
%pom_remove_plugin org.apache.commons:commons-build-plugin
%pom_remove_plugin org.apache.maven.plugins:maven-scm-publish-plugin
%pom_remove_plugin :maven-artifact-plugin
%pom_remove_plugin :cyclonedx-maven-plugin
%pom_remove_plugin :spdx-maven-plugin
%pom_remove_plugin :moditect-maven-plugin

# Plugins useless in package builds
%pom_remove_plugin :apache-rat-plugin
%pom_remove_plugin :buildnumber-maven-plugin
%pom_remove_plugin :maven-site-plugin
%pom_remove_plugin :maven-source-plugin
%pom_remove_plugin :versions-maven-plugin

# Unused dependencies
%pom_remove_dep -r :junit-bom

# Remove profiles for plugins that are useless in package builds
for profile in animal-sniffer japicmp jacoco ; do
    %pom_xpath_remove "pom:profile[pom:id='$profile']"
done

%build

%install
# pom
install -d -m 755 %{buildroot}%{_mavenpomdir}/%{name}
install -pm 644 pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{short_name}.pom
%add_maven_depmap %{name}/%{short_name}.pom

%files -f .mfiles
%doc RELEASE-NOTES.txt
%license LICENSE.txt NOTICE.txt

%changelog
* Thu Nov  7 2024 Gus Kenion <gus.kenion@suse.com>
- Upgrade to version 78
  * Maintenance and update dependencies
    + Full list of updated dependencies for all versions can be
    found in RELEASE-NOTES.txt in source archive
  * New features
    + Add property commons.asm.version with the value "9.7.1".
    + Add property commons.taglist.version with the value "3.2.1";
    fixes
    + https://github.com/mojohaus/taglist-maven-plugin/issues/165.
  * Changes
    + Fix spotbugs:check on Java 24-ea.
- Includes changes from version 77
  * Fixed bugs
    + Pin maven-pmd-plugin to 3.24.0, site compatibility is broken
    in 3.25.0.
  * Maintenance and update dependencies
  * Removed
    + Remove "cobertura" profile, we use JaCoco, Cobertura is
    unmaintained.
- Includes changes from version 76
  * Maintenance and update dependencies
- Includes changes from version 75
  * Maintenance and update dependencies
- Includes changes from version 74
  * Maintenance and update dependencies
- Includes changes from version 73
  * Maintenance and update dependencies
- Includes changes from version 72
  * New features
    + Add org.codehaus.mojo:taglist-maven-plugin:3.1.0 to plugin
    + management.
  * Maintenance and update dependencies
* Thu Jul 11 2024 Gus Kenion <gus.kenion@suse.com>
- Upgrade to version 71
  * Maintenance and update dependencies
    + Full list of updated dependencies for all versions can be
    found in RELEASE-NOTES.txt in source archive
- Update upstream source to GitHub
- Includes changes from version 70
  * New features:
    + Add profile benchmark for JMH benchmarks.
    + Add JMH to dependency management section.
  * Fixed Bugs:
    + Set Javadoc link to latest Java API LTS version.
    + Set Jacoco defaults to 1.00.
  * Update dependencies
- Includes changes from version 69
  * Maintenance and update dependencies
- Includes changes from version 68
  * Maintenance and update dependencies
- Includes changes from version 67
  * Maintenance and update dependencies
- Includes changes from version 66
  * New features:
    + Add property commons.javadoc21.java.link.
    + Add artifact:check-buildplan to the validate phase.
  * Fixed Bugs:
    + Drop markmail from mailingList section
  * Update dependencies
- Includes changes from version 65
  * New features:
    + Add exec-maven-plugin to plugin management section.
  * Fixed Bugs:
    + s/commons.surefire-report.version/commons.surefire.version/
    incorrectly added in 714c3a9
  * Update dependencies
- Includes changes from version 64
  * New features:
    + Restore building on Java 8 (com.puppycrawl.tools:checkstyle
    10.x requires Java 11).
    + Rename profile 'moditect' to 'java-9-up'.
    + Merge profile 'jdk9-compiler' into 'java-9-up' and remove
    'jdk9-compiler'.
  * Changes:
    + Use Checkstyle 9.x on Java less than 11 and Checkstyle 10.x
    on Java 11 and up.
  * Removed:
    + Remove 'javasvn' profile.
    + Remove '.svn'-activated profile.
    + Remove 'jdk9-compiler.' profile.
- Includes changes from version 63
  * New features:
    + Add commons.conf.dir property defaulting to src/conf.
  * Update dependencies
  * Removed:
    + Remove obsolete Travis CI profiles.
- Includes changes from version 62
  * Fixed Bugs:
    + Use addServiceUses when generating JPMS module info.
- Includes changes from version 61
  * Fixed Bugs:
    + Always use version.maven-source-plugin 3.2.1 (workaround
    MSOURCES-143).
- Includes changes from version 60
  * New features:
    + Add SPDX SBOM in the package phase.
  * Fixed Bugs:
    + Reuse the parent POM's maven-enforcer-plugin configuration
    + Workaround MSOURCES-143 by using version.maven-source-plugin
    3.2.1 on Java 8.
    + Remove property commons.source-plugin.version and reuse the
    parent POM's version.maven-source-plugin.
  * Update dependencies
- Includes changes from version 59
  * New features:
    + Add moditect profile for JPMS on Java >= 9.
    + Add POM property commons.javadoc.javaee8.link.
    + Add POM property commons.javadoc.javaee9.link.
    + Add POM property commons.javadoc.javaee9.1.link.
    + Add POM property commons.javadoc.javaee10.link.
    + Don't use the animal sniffer plugin on Java >=9, use the
    release flag instead.
  * Update dependencies
- Includes changes from version 58
  * New features:
    + Add commons.javadoc20.java.link.
  * Update dependencies
- Includes changes from version 57
  * Fixed Bugs:
    + Fix cyclonedx-maven-plugin configuration for multi-module
    projects.
    + Drop non-reproducible Implementation-Build in jar #242.
    + Use Java compiler release flag when compiling with Java >= 9.
  * Update dependencies
- Includes changes from version 56
  * Fixed Bugs:
    + Add Privacy link to site.xml
  * Update dependencies
- Includes changes from version 55
  * Changes:
    + Make CycloneDX work better with multi-module projects.
    + New interface methods must be default methods to maintain BC.
    + Add property commons.javadoc19.java.link.
  * Update dependencies
- Includes changes from version 54
  * New features:
    + Add .vscode/* to RAT excludes.
    + Add property commons.javadoc18.java.link.
    + Add JUnit BOM to dependency management.
    + Add CycloneDX SBOM generation #122.
    + Add SPDX SBOM generation.
  * Update dependencies
* Wed Aug 10 2022 David Anes <david.anes@suse.com>
- Upgrade to version 53
- Changes:
  * New features:
  - Add .asf.yaml to RAT excludes.
  - Add versions-maven-plugin run for this build.
  - Add maven-checkstyle-plugin to pluginManagement.
  - Allow Maven PMD plugin to override PMD implementation jars
    with property "commons.pmd-impl.version".
  - Add property commons.javadoc16.java.link.
  - Add and use property commons.enforcer-plugin.version.
  - Add SpotBugs to plugin management section.
  - Add and use property commons.buildnumber-plugin.version.
  - Add property commons.javadoc17.java.link.
  * Fixed Bugs:
  - Use HTTPS for Javadoc links to Oracle.
  - Use HTTPS for most links to Apache.
  - Rename property biz.aQute.bndlib.version ->
    commons.biz.aQute.bndlib.version.
  * Changes:
  - Bump versions-maven-plugin from 2.7 to 2.10.0
  - Bump maven-project-info-reports-plugin from 3.1.0 to 3.2.2
  - Bump Jacoco from 0.8.5 to 0.8.7
  - Bump actions/setup-java from v1.4.0 to v2
  - Bump commons-build-plugin 1.11 -> 1.12
  - Bump biz.aQute.bndlib from 5.1.2 to 6.2.0
  - Bump actions/checkout from 2.3.1 to 3
  - Bump com.github.siom79.japicmp:japicmp-maven-plugin
    0.14.3 -> 0.15.7
  - Bump org.apache.maven.wagon:wagon-ssh 3.4.0 -> 3.4.3
  - Bump maven-pmd-plugin 3.13.0 -> 3.16.0
  - Bump commons.checkstyle-plugin.version 3.1.1 -> 3.1.2
  - Bump actions/cache from 2 to 3
  - Bump animal-sniffer-maven-plugin from 1.19 to 1.21
  - Bump com.puppycrawl.tools:checkstyle from 8.40 to 9.0.2
  - Bump maven-bundle-plugin from 5.1.1 to 5.1.4
  - Bump maven-jxr-plugin from 3.0.0 to 3.1.1
  - Bump maven-javadoc-plugin from 3.2.0 to 3.3.2
  - Bump commons.pmd-impl.version from 6.29.0 to 6.44.0
  - Bump spotbugs-maven-plugin from 4.0.4 to 4.5.3.0
  - Bump spotbugs from 4.0.6 to 4.5.3
  - Bump maven-enforcer-plugin from 3.0.0-M3 to 3.0.0
  - Bump buildnumber-maven-plugin from 1.4 to 3.0.0
  - Bump maven-site-plugin from 3.9.1 to 3.11.0
  - Bump wagon-ssh from 3.4.3 to 3.5.1
  - Bump checkstyle from 9.2 to 9.3
  - Bump maven-compiler-plugin from 3.8.1 to 3.10.1
  - Bump maven-jar-plugin from 3.2.0 to 3.2.2
  - Bump commons-release-plugin from 1.7 to 1.8.0
* Tue Oct 27 2020 Pedro Monreal <pmonreal@suse.com>
- Upgrade to version 52
- Full changelog:
  * github.com/apache/commons-parent/blob/master/RELEASE-NOTES.txt
* Fri Apr  5 2019 Fridrich Strba <fstrba@suse.com>
- Make the package suitable for building with maven. Do not patch
  out useful plugins.
* Tue Oct 23 2018 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 47 and cleanup the pom file installation
* Fri May 19 2017 tchvatal@suse.com
- Do not require java-devel for build
* Fri May 19 2017 pcervinka@suse.com
- New build dependency: javapackages-local
- Fixed requires
- Spec file cleaned
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Mon Apr 14 2014 darin@darins.net
- add xz buildrequires for sles
- add buildroot for sles
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Tue Aug 27 2013 mvyskocil@suse.com
- update to 32
  * sync versions of various components in pom.xml
- use add_maven_depmap from last javapackages-tools
- dropped:
  * apache-commons-parent-remove-build-plugin.patch
* Tue Feb 28 2012 mvyskocil@suse.cz
- add missing provides/obsoletes to package
  now provides jakarta-commons-parent and commons-parent
* Wed Feb  8 2012 mvyskocil@suse.cz
- rename to apache-commons-parent to be sync with jpp and Fedora
- update to release 23
  * java-1.7 profile
  * ssh/scp support to maven-site-plugin in Maven3
* Fri Jan 29 2010 mvyskocil@suse.cz
- fixed bnc#575115 - corrected license tag
* Wed Jan 27 2010 mvyskocil@suse.cz
- initial SUSE packaging (jakarta-commons-parent-11-1.jpp5.src.rpm)
